| register_knitr_engine | R Documentation |
Call this function in a vignette's setup chunk to enable {arl} code
chunks. The engine evaluates Arl code using a shared Engine
instance that persists across chunks within a single document.
register_knitr_engine()
NULL (invisibly); called for its side effect of registering the engine.
# In a vignette setup chunk:
arl::register_knitr_engine()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.